import { Link } from "wouter";
import { ShoppingBag, Menu } from "lucide-react";
import { Button } from "@/components/ui/button";
import {
  Sheet,
  SheetContent,
  SheetHeader,
  SheetTitle,
  SheetTrigger,
} from "@/components/ui/sheet";
import { useCart } from "../cart/cart-context";
import { Logo } from "@/components/ui/logo";

export function Header() {
  const { state: cart } = useCart();

  return (
    <header className="fixed w-full bg-white/80 backdrop-blur-sm border-b z-50">
      <div className="container mx-auto px-4 h-16 flex items-center justify-between">
        <Link href="/">
          <a className="hover:opacity-80 transition-opacity">
            <Logo />
          </a>
        </Link>

        {/* Desktop Navigation */}
        <nav className="hidden md:flex items-center space-x-8">
          <Link href="/products">
            <a className="text-sm font-medium hover:text-primary">Products</a>
          </Link>
          <Link href="/about">
            <a className="text-sm font-medium hover:text-primary">About</a>
          </Link>
          <Link href="/contact">
            <a className="text-sm font-medium hover:text-primary">Contact</a>
          </Link>
          <Link href="/cart">
            <Button variant="ghost" size="icon" className="relative">
              <ShoppingBag className="h-5 w-5" />
              {cart.items.length > 0 && (
                <span className="absolute -top-1 -right-1 bg-primary text-primary-foreground rounded-full w-5 h-5 text-xs flex items-center justify-center">
                  {cart.items.length}
                </span>
              )}
            </Button>
          </Link>
        </nav>

        {/* Mobile Navigation */}
        <Sheet>
          <SheetTrigger asChild className="md:hidden">
            <Button variant="ghost" size="icon">
              <Menu className="h-5 w-5" />
            </Button>
          </SheetTrigger>
          <SheetContent>
            <SheetHeader>
              <SheetTitle>
                <Logo />
              </SheetTitle>
            </SheetHeader>
            <nav className="flex flex-col space-y-4 mt-8">
              <Link href="/products">
                <a className="text-lg font-medium hover:text-primary">Products</a>
              </Link>
              <Link href="/about">
                <a className="text-lg font-medium hover:text-primary">About</a>
              </Link>
              <Link href="/contact">
                <a className="text-lg font-medium hover:text-primary">Contact</a>
              </Link>
              <Link href="/cart">
                <a className="text-lg font-medium hover:text-primary">Cart ({cart.items.length})</a>
              </Link>
            </nav>
          </SheetContent>
        </Sheet>
      </div>
    </header>
  );
}