import { Link } from "wouter";
import { Product } from "@shared/schema";
import { Card, CardContent, CardFooter } from "@/components/ui/card";
import { AspectRatio } from "@/components/ui/aspect-ratio";

interface ProductCardProps {
  product: Product;
}

export function ProductCard({ product }: ProductCardProps) {
  return (
    <Link href={`/product/${product.id}`}>
      <a className="block group">
        <Card className="border-0 shadow-none group-hover:shadow-md transition-shadow">
          <CardContent className="p-0">
            <AspectRatio ratio={1}>
              <img
                src={product.images[0]}
                alt={product.name}
                className="object-cover w-full h-full rounded-t-lg"
              />
            </AspectRatio>
          </CardContent>
          <CardFooter className="flex flex-col items-start p-4">
            <h3 className="font-medium">{product.name}</h3>
            <p className="text-muted-foreground mt-1">
              ${parseFloat(product.price).toFixed(2)}
            </p>
          </CardFooter>
        </Card>
      </a>
    </Link>
  );
}
