import { useQuery } from "@tanstack/react-query";
import { Product } from "@shared/schema";
import { ProductGrid } from "@/components/product/product-grid";

export default function Home() {
  const { data: products, isLoading } = useQuery<Product[]>({
    queryKey: ["/api/products"],
  });

  return (
    <div className="flex flex-col">
      {/* Hero Section */}
      <section className="relative h-[70vh] flex items-center">
        <div 
          className="absolute inset-0 z-0"
          style={{
            backgroundImage: "url('https://images.unsplash.com/photo-1484327973588-c31f829103fe')",
            backgroundSize: "cover",
            backgroundPosition: "center",
            filter: "brightness(0.7)"
          }}
        />
        <div className="container mx-auto px-4 relative z-10">
          <div className="max-w-2xl text-white">
            <h1 className="text-5xl font-bold mb-4">Luxury Redefined</h1>
            <p className="text-xl mb-8">
              Discover our collection of handcrafted leather bags, where timeless elegance meets contemporary design.
            </p>
            <a 
              href="/products"
              className="inline-block bg-white text-black px-8 py-3 rounded-md font-medium hover:bg-primary hover:text-white transition-colors"
            >
              Shop Collection
            </a>
          </div>
        </div>
      </section>

      {/* Featured Products */}
      <section className="py-20 bg-white">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-12">Featured Products</h2>
          {isLoading ? (
            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-6">
              {[...Array(4)].map((_, i) => (
                <div key={i} className="animate-pulse">
                  <div className="bg-muted aspect-square rounded-lg mb-4" />
                  <div className="h-4 bg-muted rounded w-3/4 mb-2" />
                  <div className="h-4 bg-muted rounded w-1/4" />
                </div>
              ))}
            </div>
          ) : products ? (
            <ProductGrid products={products.slice(0, 4)} />
          ) : null}
        </div>
      </section>

      {/* Brand Story */}
      <section className="py-20 bg-muted/20">
        <div className="container mx-auto px-4">
          <div className="grid md:grid-cols-2 gap-12 items-center">
            <img 
              src="https://images.unsplash.com/photo-1522202176988-66273c2fd55f"
              alt="Our Workshop"
              className="rounded-lg"
            />
            <div>
              <h2 className="text-3xl font-bold mb-6">Crafted with Passion</h2>
              <p className="text-muted-foreground mb-4">
                At Limp Lambskin, we believe in the power of exceptional craftsmanship. Each bag is meticulously handcrafted by our skilled artisans, using only the finest leather materials.
              </p>
              <p className="text-muted-foreground mb-6">
                Our commitment to quality and attention to detail ensures that every piece tells a unique story of luxury and sophistication.
              </p>
              <a 
                href="/about"
                className="text-primary font-medium hover:underline"
              >
                Learn More About Us →
              </a>
            </div>
          </div>
        </div>
      </section>

      {/* Newsletter Section */}
      <section 
        className="py-20 bg-cover bg-center text-white"
        style={{
          backgroundImage: "url('https://images.unsplash.com/photo-1515378791036-0648a3ef77b2')",
          backgroundPosition: "center",
        }}
      >
        <div className="container mx-auto px-4 text-center">
          <h2 className="text-3xl font-bold mb-4">Stay Connected</h2>
          <p className="text-lg mb-8 max-w-2xl mx-auto">
            Subscribe to our newsletter and be the first to know about new collections, exclusive offers, and fashion insights.
          </p>
          {/* Newsletter form is handled in the Footer component */}
        </div>
      </section>
    </div>
  );
}
